Combines multiple validation objects of the same class into one. Works with
both single-file validation objects (hub_validations, target_validations)
and multi-file collection objects (hub_validations_collection,
target_validations_collection). For more details on these classes,
see article on <hub_validations> S3 class objects.
Details
For hub_validations objects, all inputs must share the same where
attribute (i.e., be validations for the same subject).
For hub_validations_collection objects, the individual hub_validations
objects from all collections are extracted and grouped by their where
attribute, combining validation results for the same subject.
Subclasses (e.g., target_validations, target_validations_collection) are
preserved.